[← Back to API Documentation index](index.md)

# Grouping and aggregation cards
When API_ALLOW_GROUPBY <configuration.html#ALLOW_GROUPBY> or
API_ALLOW_AGGREGATION <configuration.html#ALLOW_AGGREGATION> is enabled the generated
Redoc/Swagger spec automatically surfaces the extra query parameters.
You will see dedicated cards explaining the `groupby` and aggregation
syntax along with parameter entries for `groupby` and `aggregation`.
This keeps the interactive docs aligned with the grouping guide
and helps client developers discover the available summarisation options.

